@@ -50,19 +50,19 @@ cat(paste("Replication: ",r,"\n",sep=""))
 stat<-c("chi12","chi13","chi23","pseudo12.CoxSnell","pseudo13.CoxSnell","pseudo23.CoxSnell","pseudo12.Nagelkerke","pseudo13.Nagelkerke","pseudo23.Nagelkerke","pseudo12.McFadden","pseudo13.McFadden","pseudo23.McFadden","beta12")
 cutoff<-matrix(NA,ni,length(stat))
 for (i in 1:ni) {
-cutoff[i,1]<-getcutoff(chi12[,i],alpha,FALSE)
-cutoff[i,2]<-getcutoff(chi13[,i],alpha,FALSE)
-cutoff[i,3]<-getcutoff(chi23[,i],alpha,FALSE)
-cutoff[i,4]<-getcutoff(pseudo12.CoxSnell[,i],alpha,TRUE)
-cutoff[i,5]<-getcutoff(pseudo13.CoxSnell[,i],alpha,TRUE)
-cutoff[i,6]<-getcutoff(pseudo23.CoxSnell[,i],alpha,TRUE)
-cutoff[i,7]<-getcutoff(pseudo12.Nagelkerke[,i],alpha,TRUE)
-cutoff[i,8]<-getcutoff(pseudo13.Nagelkerke[,i],alpha,TRUE)
-cutoff[i,9]<-getcutoff(pseudo23.Nagelkerke[,i],alpha,TRUE)
-cutoff[i,10]<-getcutoff(pseudo12.McFadden[,i],alpha,TRUE)
-cutoff[i,11]<-getcutoff(pseudo13.McFadden[,i],alpha,TRUE)
-cutoff[i,12]<-getcutoff(pseudo23.McFadden[,i],alpha,TRUE)
-cutoff[i,13]<-getcutoff(beta12[,i],alpha,TRUE)
+cutoff[i,1]<-getcutoff(chi12[,i],alpha,F)
+cutoff[i,2]<-getcutoff(chi13[,i],alpha,F)
+cutoff[i,3]<-getcutoff(chi23[,i],alpha,F)
+cutoff[i,4]<-getcutoff(pseudo12.CoxSnell[,i],alpha,T)
+cutoff[i,5]<-getcutoff(pseudo13.CoxSnell[,i],alpha,T)
+cutoff[i,6]<-getcutoff(pseudo23.CoxSnell[,i],alpha,T)
+cutoff[i,7]<-getcutoff(pseudo12.Nagelkerke[,i],alpha,T)
+cutoff[i,8]<-getcutoff(pseudo13.Nagelkerke[,i],alpha,T)
+cutoff[i,9]<-getcutoff(pseudo23.Nagelkerke[,i],alpha,T)
+cutoff[i,10]<-getcutoff(pseudo12.McFadden[,i],alpha,T)
+cutoff[i,11]<-getcutoff(pseudo13.McFadden[,i],alpha,T)
+cutoff[i,12]<-getcutoff(pseudo23.McFadden[,i],alpha,T)
+cutoff[i,13]<-getcutoff(beta12[,i],alpha,T)
 }
 colnames(cutoff)<-stat
 rownames(cutoff)<-paste("I",selection,sep="")
